@@ -136,7 +136,7 @@ from __future__ import with_statement
 
 __ver_major__ = 0
 __ver_minor__ = 8
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 __version__ = "%d.%d.%d%s" % __ver_tuple__
@@ -942,6 +942,9 @@ def run_startup_hooks():
         time.sleep(10)        
         app.cleanup()
         sys.exit(0)
+    # Let esky.slaveproc run its hooks.
+    import esky.slaveproc
+    esky.slaveproc.run_startup_hooks()
     # Let esky.sudo run its hooks.
     import esky.sudo
     esky.sudo.run_startup_hooks()
