@@ -67,15 +67,14 @@ else:
                   ctypes.windll.kernel32.TerminateProcess(int(proc._handle),-1)
                else:
                   os.kill(proc.pid,signal.SIGTERM)
+            proc.wait()
     spawn_busy_loop(app)
 
 #  Upgrade to the next version (0.2, even though 0.3 is available)
 if os.environ.get("ESKY_NEEDSROOT",""):
     already_root = app.has_root()
-    print "GETTING ROOT"
     app.get_root()
     assert app.has_root()
-    print "GOT ROOT"
     app.drop_root()
     assert app.has_root() == already_root
     app.get_root()
